@@ -435,7 +435,7 @@ class CLIArgument(BaseCLIArgument):
             # below.  Sometimes this can be more complicated, and subclasses
             # can customize as they need.
             unpacked = self._unpack_argument(value)
-            LOG.debug('Unpacked value of "%s" for parameter "%s": %s', value,
+            LOG.debug('Unpacked value of %r for parameter "%s": %r', value,
                       self.py_name, unpacked)
             parameters[self._serialized_name] = unpacked
 
