@@ -11,7 +11,19 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import sys
-import six
+
+from botocore.compat import six
+#import botocore.compat
+
+# If you ever want to import from the vendored six. Add it here and then
+# import from awscli.compat. Also try to keep it in alphabetical order.
+# This may get large.
+advance_iterator = six.advance_iterator
+PY3 = six.PY3
+queue = six.moves.queue
+shlex_quote = six.moves.shlex_quote
+StringIO = six.StringIO
+urlopen = six.moves.urllib.request.urlopen
 
 if six.PY3:
     import locale
