@@ -74,30 +74,39 @@ class CloudTrailSubscribe(BasicCommand):
     UPDATE = False
 
     def _run_main(self, args, parsed_globals):
-        endpoint_args = {
-            'region_name': None,
-            'endpoint_url': None
-        }
-        if 'region' in parsed_globals:
-            endpoint_args['region_name'] = parsed_globals.region
-        if 'endpoint_url' in parsed_globals:
-            endpoint_args['endpoint_url'] = parsed_globals.endpoint_url
-
-        # Initialize services
-        LOG.debug('Initializing S3, SNS and CloudTrail...')
-        self.iam = Service('iam', session=self._session)
-        self.s3 = Service('s3', endpoint_args['region_name'],
-                          session=self._session)
-        self.sns = Service('sns', endpoint_args['region_name'],
-                           session=self._session)
-        self.cloudtrail = Service('cloudtrail', endpoint_args=endpoint_args,
-                                  session=self._session)
-
+        self.setup_services(args, parsed_globals)
         # Run the command and report success
         self._call(args, parsed_globals)
 
         return 1
 
+    def setup_services(self, args, parsed_globals):
+        endpoint_args = {
+            'region_name': None,
+            'endpoint_url': None,
+            'verify': None
+        }
+        if 'region' in parsed_globals:
+            endpoint_args['region_name'] = parsed_globals.region
+        if 'verify_ssl' in parsed_globals:
+            endpoint_args['verify'] = parsed_globals.verify_ssl
+
+        # Initialize services
+        LOG.debug('Initializing S3, SNS and CloudTrail...')
+        self.iam = Service('iam', endpoint_args=endpoint_args,
+                           session=self._session)
+        self.s3 = Service('s3', endpoint_args=endpoint_args,
+                          session=self._session)
+        self.sns = Service('sns', endpoint_args=endpoint_args,
+                           session=self._session)
+
+        # If the endpoint is specified, it is designated for the cloudtrail
+        # service. Not all of the other services will use it.
+        if 'endpoint_url' in parsed_globals:
+            endpoint_args['endpoint_url'] = parsed_globals.endpoint_url
+        self.cloudtrail = Service('cloudtrail', endpoint_args=endpoint_args,
+                                  session=self._session)
+
     def _call(self, options, parsed_globals):
         """
         Run the command. Calls various services based on input options and
@@ -222,7 +231,15 @@ class CloudTrailSubscribe(BasicCommand):
             raise Exception('Bucket {bucket} already exists.'.format(
                 bucket=bucket))
 
-        data = self.s3.CreateBucket(bucket=bucket)
+        # If we are not using the us-east-1 region, then we must set
+        # a location constraint on the new bucket.
+        region_name = self.s3.endpoint.region_name
+        params = {'bucket': bucket}
+        if region_name != 'us-east-1':
+            bucket_config = {'LocationConstraint': region_name}
+            params['create_bucket_configuration'] = bucket_config
+
+        data = self.s3.CreateBucket(**params)
 
         try:
             self.s3.PutBucketPolicy(bucket=bucket, policy=policy)
