@@ -526,7 +526,7 @@ class ConfigureCommand(BasicCommand):
     ]
 
     def __init__(self, session, prompter=None, config_writer=None):
-        self._session = session
+        super(ConfigureCommand, self).__init__(session)
         if prompter is None:
             prompter = InteractivePrompter()
         self._prompter = prompter
