@@ -30,7 +30,7 @@ DEBUGGING_NAME = 'Setup Hadoop Debugging'
 
 CONFIG_HADOOP_PATH = '/bootstrap-actions/configure-hadoop'
 
-EMR_FS_BA_NAME = 'Enable Consistent View in EMR-FS'
+EMR_FS_BA_NAME = 'Setup EMRFS'
 EMR_FS_BA_ARG_KEY = '-e'
 EMR_FS_CONSISTENT_KEY = 'fs.s3.consistent'
 EMR_FS_SSE_KEY = 'fs.s3.enableServerSideEncryption'
