@@ -40,7 +40,7 @@ class InstallApplications(BasicCommand):
 
         self._check_for_supported_apps(parsed_args.applications)
         parameters['Steps'] = applicationutils.build_applications(
-            parsed_args.applications, parsed_globals)[2]
+            self._session, parsed_args.applications, parsed_globals)[2]
 
         emrutils.call_and_display_response(self._session, 'AddJobFlowSteps',
                                            parameters, parsed_globals)
@@ -61,4 +61,4 @@ class InstallApplications(BasicCommand):
                 raise ValueError(
                     "aws: error: Unknown application: " + app_config['Name'] +
                     ". 'Name' should be one of the following: " +
-                    ', '.join(constants.APPLICATIONS))
\ No newline at end of file
+                    ', '.join(constants.APPLICATIONS))
