@@ -89,6 +89,12 @@ class StreamingOutputArgument(BaseCLIArgument):
             service_name, operation_name), self.save_file)
 
     def save_file(self, parsed, **kwargs):
+        if self._response_key not in parsed:
+            # If the response key is not in parsed, then
+            # we've received an error message and we'll let the AWS CLI
+            # error handler print out an error message.  We have no
+            # file to save in this situation.
+            return
         body = parsed[self._response_key]
         buffer_size = self._buffer_size
         with open(self._output_file, 'wb') as fp:
