@@ -36,7 +36,6 @@ from awscli.customizations.sessendemail import register_ses_send_email
 from awscli.customizations.iamvirtmfa import IAMVMFAWrapper
 from awscli.customizations.argrename import register_arg_renames
 from awscli.customizations.dryrundocs import register_dryrun_docs
-from awscli.customizations.route53resourceid import register_resource_id
 from awscli.customizations.configure import register_configure_cmd
 from awscli.customizations.cloudtrail import initialize as cloudtrail_init
 from awscli.customizations.toplevelbool import register_bool_params
@@ -59,6 +58,7 @@ from awscli.customizations.configservice.getstatus import register_get_status
 from awscli.customizations.configservice.rename_cmd import \
     register_rename_config
 from awscli.customizations.scalarparse import register_scalar_parser
+from awscli.customizations.opsworks import initialize as opsworks_init
 
 
 def awscli_initialize(event_handlers):
@@ -102,7 +102,6 @@ def awscli_initialize(event_handlers):
     IAMVMFAWrapper(event_handlers)
     register_arg_renames(event_handlers)
     register_dryrun_docs(event_handlers)
-    register_resource_id(event_handlers)
     register_configure_cmd(event_handlers)
     cloudtrail_init(event_handlers)
     register_bool_params(event_handlers)
@@ -120,3 +119,4 @@ def awscli_initialize(event_handlers):
     register_get_status(event_handlers)
     register_rename_config(event_handlers)
     register_scalar_parser(event_handlers)
+    opsworks_init(event_handlers)
